@@ -1,27 +1,16 @@
-/***************************************************************************
- *   Copyright (C) 2009 Ben Cooksley <bcooksley@kde.org>                   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2009 Ben Cooksley <bcooksley@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #ifndef BASEDATA_H
 #define BASEDATA_H
 
 #include <QObject>
 
+#include "systemsettingsview_export.h"
+
 class QString;
 class MenuItem;
 class KConfigGroup;
@@ -34,7 +23,7 @@ class KConfigGroup;
  *
  * @author Ben Cooksley <bcooksley@kde.org>
  */
-class BaseData : public QObject
+class SYSTEMSETTINGSVIEW_EXPORT BaseData : public QObject
 {
     Q_OBJECT
     Q_DISABLE_COPY(BaseData)
