@@ -55,7 +55,7 @@ BaseMode::~BaseMode()
     delete d;
 }
 
-void BaseMode::init(const KPluginMetaData metaData)
+void BaseMode::init(const KPluginMetaData &metaData)
 {
     d->rootItem = BaseData::instance()->menuItem();
     d->homeItem = BaseData::instance()->homeItem();
@@ -99,16 +99,6 @@ const KPluginMetaData &BaseMode::metaData() const
     return d->metaData;
 }
 
-void BaseMode::setShowToolTips(bool show)
-{
-    d->showToolTips = show;
-}
-
-bool BaseMode::showToolTips() const
-{
-    return d->showToolTips;
-}
-
 void BaseMode::setStartupModule(const QString &startupModule)
 {
     d->startupModule = startupModule;
@@ -178,3 +168,12 @@ QList<QAbstractItemView *> BaseMode::views() const
 {
     return QList<QAbstractItemView *>();
 }
+
+bool BaseMode::defaultsIndicatorsVisible() const
+{
+    return false;
+}
+
+void BaseMode::toggleDefaultsIndicatorsVisibility()
+{
+}
